@@ -3,7 +3,7 @@ from typing import List, Optional
 from .songs import *
 
 
-def parse_playlist_items(results, menu_entries: Optional[List[List]] = None):
+def parse_playlist_items(results, menu_entries: Optional[List[List]] = None, is_album=False):
     songs = []
     for result in results:
         if MRLIR not in result:
@@ -46,13 +46,9 @@ def parse_playlist_items(results, menu_entries: Optional[List[List]] = None):
 
         artists = parse_song_artists(data, 1)
 
-        album = parse_song_album(data, 2)
+        album = parse_song_album(data, 3)
 
-        views = None
-        if album and album["id"] is None:
-            # views currently only present on albums and formatting is localization-dependent -> no parsing
-            if (views := (get_item_text(data, 2))) is not None:
-                album = None
+        views = get_item_text(data, 2)
 
         duration = None
         if "fixedColumns" in data:
@@ -75,7 +71,7 @@ def parse_playlist_items(results, menu_entries: Optional[List[List]] = None):
 
         videoType = nav(
             data,
-            MENU_ITEMS + [0, "menuNavigationItemRenderer", "navigationEndpoint"] + NAVIGATION_VIDEO_TYPE,
+            [*MENU_ITEMS, 0, MNIR, "navigationEndpoint", *NAVIGATION_VIDEO_TYPE],
             True,
         )
 
@@ -92,6 +88,10 @@ def parse_playlist_items(results, menu_entries: Optional[List[List]] = None):
             "videoType": videoType,
             "views": views,
         }
+
+        if is_album:
+            song["trackNumber"] = int(nav(data, ["index", "runs", 0, "text"])) if isAvailable else None
+
         if duration:
             song["duration"] = duration
             song["duration_seconds"] = parse_duration(duration)
